@@ -1,7 +1,8 @@
 # -*- coding: utf-8 -*-
 
-from .brennenstuhl_gateway import BrennenstuhlGateway
 from .gateway import Gateway
+from .brennenstuhl_gateway import BrennenstuhlGateway
 from .intertechno_gateway import IntertechnoGateway
+from .connair_gateway import ConnAirGateway
 
-__all__ = ['Gateway', 'IntertechnoGateway', 'BrennenstuhlGateway']
+__all__ = ["Gateway", "IntertechnoGateway", "BrennenstuhlGateway", "ConnAirGateway"]
